@@ -56,9 +56,9 @@
   #:use-module (rnrs bytevectors)
   #:use-module ((system foreign) #:prefix ffi:)
   #:use-module (srfi srfi-9)
-  #:version (1 01 1))
+  #:version (1 01 2))
 
-(define *ffi-help-version* "1.01.1")
+(define *ffi-help-version* "1.01.2")
 
 (define (sferr fmt . args) (apply simple-format (current-error-port) fmt args))
 
@@ -385,12 +385,13 @@
        (quote type)
        (lambda (obj) ;; unwrap => pointer
 	 (ffi:bytevector->pointer (bytestructure-bytevector obj)))
-       (lambda* (size #:optional (size 0))
+       (lambda* (val #:optional (size 0))
 	 (cond
 	  ((bytevector? val)
 	   (make-struct/no-tail
 	    type (make-bytestructure val 0 (fh:vector& base-desc))))
 	  ((ffi:pointer? val) (make (ffi:pointer->bytevector val size)))
+	  ((integer? val) (make (ffi:make-pointer val) size))
 	  (else (error "ffi-help-rt: bad spec" val))))
        #f #f
        (make-bs-printer (quote type))))
